@@ -102,6 +102,9 @@ UiUtils::SortedConnectionType UiUtils::connectionTypeToSortedType(NetworkManager
         case NetworkManager::ConnectionSettings::Wireless:
             return UiUtils::Wireless;
             break;
+        case NetworkManager::ConnectionSettings::WireGuard:
+            return UiUtils::Wireguard;
+            break;
         default:
             return UiUtils::Unknown;
             break;
@@ -110,11 +113,7 @@ UiUtils::SortedConnectionType UiUtils::connectionTypeToSortedType(NetworkManager
 
 bool UiUtils::isConnectionTypeSupported(NetworkManager::ConnectionSettings::ConnectionType type)
 {
-#if NM_CHECK_VERSION(1, 2, 0)
     if (type == NetworkManager::ConnectionSettings::Generic || type == NetworkManager::ConnectionSettings::Tun) {
-#else
-    if (type == NetworkManager::ConnectionSettings::Generic) {
-#endif
         return false;
     }
 
@@ -131,6 +130,19 @@ bool UiUtils::isConnectionTypeSupported(NetworkManager::ConnectionSettings::Conn
     return true;
 }
 
+bool UiUtils::isConnectionTypeVirtual(NetworkManager::ConnectionSettings::ConnectionType type)
+{
+    if (type == NetworkManager::ConnectionSettings::Bond ||
+        type == NetworkManager::ConnectionSettings::Bridge ||
+        type == NetworkManager::ConnectionSettings::Infiniband ||
+        type == NetworkManager::ConnectionSettings::Team ||
+        type == NetworkManager::ConnectionSettings::Vlan) {
+        return true;
+    }
+
+   return false;
+}
+
 QString UiUtils::interfaceTypeLabel(const NetworkManager::Device::Type type, const NetworkManager::Device::Ptr iface)
 {
     QString deviceText;
@@ -156,11 +168,9 @@ QString UiUtils::interfaceTypeLabel(const NetworkManager::Device::Type type, con
     case NetworkManager::Device::Vlan:
         deviceText = i18nc("title of the interface widget in nm's popup", "Virtual (vlan)");
         break;
-#if NM_CHECK_VERSION(0, 9, 10)
     case NetworkManager::Device::Team:
         deviceText = i18nc("title of the interface widget in nm's popup", "Virtual (team)");
         break;
-#endif
     case NetworkManager::Device::Modem: {
         const NetworkManager::ModemDevice::Ptr nmModemIface = iface.objectCast<NetworkManager::ModemDevice>();
         if (nmModemIface) {
@@ -237,11 +247,13 @@ QString UiUtils::iconAndTitleForConnectionSettingsType(NetworkManager::Connectio
         text = i18n("Wi-Fi");
         icon = QStringLiteral("network-wireless");
         break;
-#if NM_CHECK_VERSION(0, 9, 10)
     case ConnectionSettings::Team:
         text = i18n("Team");
         break;
-#endif
+    case ConnectionSettings::WireGuard:
+        text = i18n("WireGuard VPN");
+        icon = QStringLiteral("network-vpn");
+        break;
     default:
         text = i18n("Unknown connection type");
         break;
